@import '~@synerty/peek-plugin-base-js/src/styles/variables';
@import '~@synerty/peek-plugin-base-js/src/styles/mixins';

//peek screens

//plugin screens
@import '~@synerty/peek-plugin-base-js/src/styles/layout/_plugin_inbox';
@import '~@synerty/peek-plugin-base-js/src/styles/layout/_plugin_chat';

//generic sections
@import '~@synerty/peek-plugin-base-js/src/styles/layout/_navigation_section';
@import '~@synerty/peek-plugin-base-js/src/styles/layout/_tabs_section';
@import '~@synerty/peek-plugin-base-js/src/styles/layout/_mobile_dialog_section';

//@import '~@synerty/peek-plugin-base-js/src/styles/layout/_information_section';
.peek-information-section {
  /*
      Contains the Information Section classes
  */

  padding: $general_padding_2;

  .information-section-title {
    /*
        Contains the title attributes unique to the peek-information-section class
    */
    padding-bottom: $general_padding_2;
  }

  .information-section-icon {
    /*
        Contains the icon attributes unique to the peek-information-section class
    */
    background-image: url('@synerty/peek-plugin-base-js/src/assets/images/home_background.png');
    @include inner-shadow(0.35);
    padding: $general_padding_3;
    max-width: $general_width_1;
    height: auto;
    border-radius: $general_border_radius;
    margin-top: $general_padding_4;
    margin-bottom: $general_padding_4;
    margin-left: auto;
    margin-right: auto;
    display: block;
  }
}


@import '~@synerty/peek-plugin-base-js/src/styles/layout/_details_section';
@import '~@synerty/peek-plugin-base-js/src/styles/layout/_tables_section';

@import '~@synerty/peek-plugin-base-js/src/styles/layout/_general';

body,
html{
  height: 100%;
}

.image{
  max-width: 100%;
}

.hr{
  margin-top: 0;
  margin-bottom: 0;
}

*:focus {outline:none!important;}

.navigation-information{
  //border-bottom: 1px solid darken($grey,20%);
  margin-bottom: $general_padding_2;

  .form-group{
    padding-top: 0;
    margin-bottom: 0;
  }

}

.form-group{
  margin-bottom: 0;
  padding-bottom: $general_padding_2;
  padding-top: $general_padding_2;
  //color: $black;
}
